@@ -37,7 +37,7 @@ def pull(toolVersionId):
     template['desc'] = pullToolEntity['desc']
     template['id'] = toolEntity['id']
     auth = common.get(url=common.get_cloud_base_url() + '/tool/pass')
-    client = docker.from_env()
+    client = docker.from_env(timeout=100000000)
     print("pulling, please wait")
     client.images.pull(repository=common.get_docker_registry() + '/' + pullToolEntity['path'],
                        tag="latest",
